Quickspin
===================

Quickspin is a simple CLI tool for spinning up a series of EC2 instances.

How to install
--------------

You can install Quickspin using **pip**

::

    pip install Quickspin

or via source files with:

::

    python setup.py install

Quick start
--------------
Once installed use you can get help on use Quickspin as follows:

::
    quickspin -h
